CustomShowCaseWidget class

Inheritance

Constructors

CustomShowCaseWidget({required Builder builder, int totalWidgets = 0, VoidCallback? onFinish, dynamic onStart(int?, GlobalKey<State<StatefulWidget>>)?, dynamic onComplete(int?, GlobalKey<State<StatefulWidget>>)?, bool autoPlay = false, Duration autoPlayDelay = const Duration(milliseconds: 2000), bool enableAutoPlayLock = false, double blurValue = 0, Duration scrollDuration = const Duration(milliseconds: 300), bool disableMovingAnimation = false, bool disableScaleAnimation = false, bool enableAutoScroll = false, bool disableBarrierInteraction = false, bool enableShowcase = true})
const

Properties

autoPlay → bool
Whether all showcases will auto sequentially start having time interval of autoPlayDelay .
final
autoPlayDelay → Duration
Visibility time of current showcase when autoplay sets to true.
final
blurValue → double
Default overlay blur used by showcase. if Showcase.blurValue is not provided.
final
builder → Builder
final
disableBarrierInteraction → bool
Whether disabling barrier interaction
final
disableMovingAnimation → bool
Whether disabling bouncing/moving animation for all tooltips while showcasing
final
disableScaleAnimation → bool
Whether disabling initial scale animation for all the default tooltips when showcase is started and completed
final
enableAutoPlayLock → bool
Whether blocking user interaction while autoPlay is enabled.
final
enableAutoScroll → bool
While target widget is out viewport then whether enabling auto scroll so as to make the target widget visible.
final
enableShowcase → bool
Enable/disable showcase globally. Enabled by default.
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onComplete → dynamic Function(int?, GlobalKey<State<StatefulWidget>>)?
Triggered every time on completion of each showcase
final
onFinish → VoidCallback?
Triggered when all the showcases are completed.
final
onStart → dynamic Function(int?, GlobalKey<State<StatefulWidget>>)?
Triggered every time on start of each showcase.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scrollDuration → Duration
Provides time duration for auto scrolling when enableAutoScroll is true
final
totalWidgets → int
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → CustomShowCaseWidgetState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited