CustomShowCaseWidgetState class

Inheritance

Constructors

CustomShowCaseWidgetState()

Properties

activeWidgetId ↔ int?
getter/setter pair
autoPlay ↔ bool
getter/setter pair
autoPlayDelay ↔ Duration
getter/setter pair
blurValue → double
Returns value of CustomShowCaseWidget.blurValue
no setter
context → BuildContext
The location in the tree where this widget builds.
no setterinherited
disableBarrierInteraction ↔ bool
getter/setter pair
disableMovingAnimation ↔ bool
getter/setter pair
disableScaleAnimation ↔ bool
getter/setter pair
enableAutoPlayLock ↔ bool
getter/setter pair
enableAutoScroll ↔ bool
getter/setter pair
enableShowcase ↔ bool
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
ids ↔ List<GlobalKey<State<StatefulWidget>>>?
getter/setter pair
mounted → bool
Whether this State object is currently in a tree.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalWidgets ↔ int
getter/setter pair
widget → CustomShowCaseWidget
The current configuration.
no setterinherited

Methods

activate() → void
Called when this object is reinserted into the tree after having been removed via deactivate.
inherited
build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
completed(GlobalKey<State<StatefulWidget>>? key) → void
Completes showcase of given key and starts next one otherwise will finish the entire showcase view
deactivate() → void
Called when this object is removed from the tree.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
didChangeDependencies() → void
Called when a dependency of this State object changes.
inherited
didUpdateWidget(covariant CustomShowCaseWidget oldWidget) → void
Called whenever the widget configuration changes.
override
dismiss() → void
Dismiss entire showcase view
dispose() → void
Called when this object is removed from the tree permanently.
inherited
initState() → void
Called when this object is inserted into the tree.
override
next() → void
Completes current active showcase and starts next one otherwise will finish the entire showcase view
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
previous() → void
Completes current active showcase and starts previous one otherwise will finish the entire showcase view
reassemble() → void
Called whenever the application is reassembled during debugging, for example during hot reload.
inherited
setState(VoidCallback fn) → void
Notify the framework that the internal state of this object has changed.
inherited
startShowCase(List<GlobalKey<State<StatefulWidget>>> widgetIds) → void
Starts Showcase view from the beginning of specified list of widget ids. If this function is used when showcase has been disabled then it will throw an exception.
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited